@@ -21,7 +21,7 @@ class EtsyAuth:
     
     headers: dict
     session: OAuth2Session
-    user_info: Optional[OtherUser]
+    user_info: Optional[OtherUser] = None
     __base_endpoint:str = "https://openapi.etsy.com/v3/application/"
     
     
